shithub: pokered

Download patch

ref: 7b7c563c93155e121e05149779cfb78b0bf9d259
parent: 3870f5e10a1e17f35c78b176272df6b1f516f24e
author: YamaArashi <shadow962@live.com>
date: Sun Feb 8 13:40:08 EST 2015

Rename some labels

--- a/engine/battle/16.asm
+++ b/engine/battle/16.asm
@@ -55,7 +55,7 @@
 	ld hl, UnveiledGhostText
 	call PrintText
 	callab LoadEnemyMonData
-	callab DoGhostMarowakRevelationAnimation
+	callab MarowakAnim
 	ld hl, WildMonAppearedText
 	call PrintText
 
--- a/engine/battle/1c.asm
+++ b/engine/battle/1c.asm
@@ -1,4 +1,5 @@
-DoGhostMarowakRevelationAnimation: ; 708ca (1c:48ca)
+MarowakAnim: ; 708ca (1c:48ca)
+; animate the ghost being unveiled as a Marowak
 	ld a, $e4
 	ld [rOBP1], a
 	call CopyMonPicFromBGToSpriteVRAM ; cover the BG ghost pic with a sprite ghost pic that looks the same
--- a/engine/cable_club.asm
+++ b/engine/cable_club.asm
@@ -578,7 +578,7 @@
 
 ReturnToCableClubRoom: ; 577d (1:577d)
 	call GBPalWhiteOutWithDelay3
-	ld hl, wCharRAMInUseForText
+	ld hl, wFontLoaded
 	ld a, [hl]
 	push af
 	push hl
--- a/engine/overworld/map_sprites.asm
+++ b/engine/overworld/map_sprites.asm
@@ -159,7 +159,7 @@
 	ld l,e
 	pop de
 	ld b,a
-	ld a,[wCharRAMInUseForText]
+	ld a,[wFontLoaded]
 	bit 0,a ; reloading upper half of tile patterns after displaying text?
 	jr nz,.skipFirstLoad ; if so, skip loading data into the lower half
 	ld a,b
@@ -180,7 +180,7 @@
 	jr nc,.noCarry3
 	inc d
 .noCarry3
-	ld a,[wCharRAMInUseForText]
+	ld a,[wFontLoaded]
 	bit 0,a ; reloading upper half of tile patterns after displaying text?
 	jr nz,.loadWhileLCDOn
 	pop af
@@ -264,7 +264,7 @@
 	cp a,$f0 ; does the map have 2 sprite sets?
 	call nc,GetSplitMapSpriteSetID ; if so, choose the appropriate one
 	ld b,a ; b = spriteSetID
-	ld a,[wCharRAMInUseForText]
+	ld a,[wFontLoaded]
 	bit 0,a ; reloading upper half of tile patterns after displaying text?
 	jr nz,.loadSpriteSet ; if so, forcibly reload the sprite set
 	ld a,[W_SPRITESETID]
--- a/engine/overworld/movement.asm
+++ b/engine/overworld/movement.asm
@@ -52,7 +52,7 @@
 	jr .asm_4eab
 .asm_4e86
 	ld [wSpriteStateData1 + 9], a
-	ld a, [wCharRAMInUseForText]
+	ld a, [wFontLoaded]
 	bit 0, a
 	jr nz, .asm_4e7d
 .asm_4e90
@@ -130,7 +130,7 @@
 	bit 7, a
 	jp nz, InitializeSpriteFacingDirection  ; c1x1 >= $80
 	ld b, a
-	ld a, [wCharRAMInUseForText]
+	ld a, [wFontLoaded]
 	bit 0, a
 	jp nz, notYetMoving
 	ld a, b
--- a/home.asm
+++ b/home.asm
@@ -1183,7 +1183,7 @@
 	ld [H_LOADEDROMBANK],a
 	ld [$2000],a
 	call InitMapSprites ; reload sprite tile pattern data (since it was partially overwritten by text tile patterns)
-	ld hl,wCharRAMInUseForText
+	ld hl,wFontLoaded
 	res 0,[hl]
 	ld a,[wd732]
 	bit 3,a ; used fly warp
@@ -4540,7 +4540,7 @@
 ; Copy the current map's sprites' tile patterns to VRAM again after they have
 ; been overwritten by other tile patterns.
 ReloadMapSpriteTilePatterns:: ; 3e08 (0:3e08)
-	ld hl, wCharRAMInUseForText
+	ld hl, wFontLoaded
 	ld a, [hl]
 	push af
 	res 0, [hl]
--- a/main.asm
+++ b/main.asm
@@ -1022,7 +1022,7 @@
 .drawTextBoxBorder
 	call TextBoxBorder
 .skipDrawingTextBoxBorder
-	ld hl,wCharRAMInUseForText
+	ld hl,wFontLoaded
 	set 0,[hl]
 	ld hl,wFlags_0xcd60
 	bit 4,[hl]
--- a/wram.asm
+++ b/wram.asm
@@ -820,10 +820,11 @@
 ; LoadMonData copies mon data here
 wLoadedMon:: party_struct wLoadedMon ; cf98
 
-wCharRAMInUseForText:: ; cfc4
-; bit 0: the space in VRAM that is used to store walking tile patterns for
-;        the player and NPCs is in use for text tile patterns. this means
-;        that movement must be disabled.
+wFontLoaded:: ; cfc4
+; bit 0: The space in VRAM that is used to store walk animation tile patterns
+;        for the player and NPCs is in use for font tile patterns.
+;        This means that NPC movement must be disabled.
+; The other bits are unused.
 	ds 1
 
 wWalkCounter:: ; cfc5